@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -30,8 +30,7 @@
  *  @since 5.3
  */
 
-namespace KContacts
-{
+namespace KContacts {
 class KCONTACTS_EXPORT FieldGroup
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const FieldGroup &);
@@ -46,22 +45,22 @@ public:
     typedef QVector<FieldGroup> List;
 
     void setFieldGroupName(const QString &fieldGroup);
-    QString fieldGroupName() const;
+    Q_REQUIRED_RESULT QString fieldGroupName() const;
 
-    bool isValid() const;
+    Q_REQUIRED_RESULT bool isValid() const;
 
     void setValue(const QString &value);
-    QString value() const;
+    Q_REQUIRED_RESULT QString value() const;
 
     void setParameters(const QMap<QString, QStringList> &params);
-    QMap<QString, QStringList> parameters() const;
+    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
 
-    bool operator==(const FieldGroup &other) const;
-    bool operator!=(const FieldGroup &other) const;
+    Q_REQUIRED_RESULT bool operator==(const FieldGroup &other) const;
+    Q_REQUIRED_RESULT bool operator!=(const FieldGroup &other) const;
 
     FieldGroup &operator=(const FieldGroup &other);
 
-    QString toString() const;
+    Q_REQUIRED_RESULT QString toString() const;
 private:
     class Private;
     QSharedDataPointer<Private> d;
@@ -69,7 +68,6 @@ private:
 KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const FieldGroup &object);
 
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, FieldGroup &object);
-
 }
 Q_DECLARE_TYPEINFO(KContacts::FieldGroup, Q_MOVABLE_TYPE);
 #endif // FIELDGROUP_H
